@@ -7,11 +7,12 @@ from sqlalchemy.orm import declarative_base, sessionmaker
 
 uri = read_secret(cate1='notecoin', cate2='dataset', cate3='db_path')
 uri = uri or f'sqlite:///{os.path.abspath(os.path.dirname(__file__))}/data/notecoin.db'
-engine = create_engine(uri, echo=True)
+#engine = create_engine(uri, echo=True)
+engine = create_engine(uri)
 Base = declarative_base()
 session = sessionmaker(bind=engine)()
 
 logging.info(f'uri:{uri}')
 
 def create_all():
-    Base.metadata.create_all(engine)
\ No newline at end of file
+    Base.metadata.create_all(engine)
